@@ -932,7 +932,15 @@ class _Request:
                 raise NetworkError(self.network, e)
 
         try:
-            response_text = _unicode(conn.getresponse().read())
+            response = conn.getresponse()
+            if response.status in [500, 502, 503, 504]:
+                raise WSError(
+                    self.network,
+                    response.status,
+                    "Connection to the API failed with HTTP code "
+                    + str(response.status),
+                )
+            response_text = _unicode(response.read())
         except Exception as e:
             raise MalformedResponseError(self.network, e)
 
@@ -1134,7 +1142,12 @@ class _BaseObject:
     def _extract_cdata_from_request(self, method_name, tag_name, params):
         doc = self._request(method_name, True, params)
 
-        return doc.getElementsByTagName(tag_name)[0].firstChild.wholeText.strip()
+        first_child = doc.getElementsByTagName(tag_name)[0].firstChild
+
+        if first_child is None:
+            return None
+
+        return first_child.wholeText.strip()
 
     def _get_things(self, method, thing, thing_type, params=None, cacheable=True):
         """Returns a list of the most played thing_types by this thing."""
@@ -1713,6 +1726,15 @@ class Artist(_BaseObject, _Taggable):
             SIZE_SMALL
         """
 
+        warnings.warn(
+            "Artist.get_cover_image is deprecated and will be removed in a future "
+            "version. In the meantime, only default star images are available. "
+            "See https://github.com/pylast/pylast/issues/317 and "
+            "https://support.last.fm/t/api-announcement/202",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
         if "image" not in self.info:
             self.info["image"] = _extract_all(
                 self._request(self.ws_prefix + ".getInfo", cacheable=True), "image"
@@ -2115,6 +2137,8 @@ class Track(_Opus):
 
     def get_album(self):
         """Returns the album object of this track."""
+        if "album" in self.info and self.info["album"] is not None:
+            return Album(self.artist, self.info["album"], self.network)
 
         doc = self._request(self.ws_prefix + ".getInfo", True)
 
@@ -2325,8 +2349,9 @@ class User(_BaseObject, _Chartable):
 
         artist = _extract(e, "artist")
         title = _extract(e, "name")
+        info = {"album": _extract(e, "album"), "image": _extract_all(e, "image")}
 
-        return Track(artist, title, self.network, self.name)
+        return Track(artist, title, self.network, self.name, info=info)
 
     def get_recent_tracks(self, limit=10, cacheable=True, time_from=None, time_to=None):
         """
